Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(357)

Unified Diff: service/datastore/errors.go

Issue 1259593005: Add 'user friendly' datastore API. (Closed) Base URL: https://github.com/luci/gae.git@master
Patch Set: 100% coverage of new code Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: service/datastore/errors.go
diff --git a/service/rawdatastore/errors.go b/service/datastore/errors.go
similarity index 93%
rename from service/rawdatastore/errors.go
rename to service/datastore/errors.go
index 6ab0b563733268fc66c6ed1833e8d21ab46c0869..b71415652bc1c80c061310ad550552feee1f5096 100644
--- a/service/rawdatastore/errors.go
+++ b/service/datastore/errors.go
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-package rawdatastore
+package datastore
import (
"fmt"
@@ -11,7 +11,7 @@ import (
"google.golang.org/appengine/datastore"
)
// These errors are returned by various rawdatastore.Interface methods.
var (
ErrInvalidEntityType = datastore.ErrInvalidEntityType
ErrInvalidKey = datastore.ErrInvalidKey
@@ -11,7 +11,7 @@ import (
"google.golang.org/appengine/datastore"
)
-// These errors are returned by various rawdatastore.Interface methods.
+// These errors are returned by various datastore.Interface methods.
var (
ErrInvalidEntityType = datastore.ErrInvalidEntityType

Powered by Google App Engine
This is Rietveld 408576698